'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getVolumeIcon = exports.getVolumeChangeStyle = exports.getTransformProperty = exports.getPercentPlayed = exports.getTimeFormatFromCurrentTime = exports.getFullscreenProperties = exports.getControlStyle = exports.getControlsContainerStyle = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; // icons


var _icons = require('./icons');

var TEST_DIV = document.createElement('div');

/**
 * get the style for the controls container based on isControlsVisible
 *
 * @param {object} defaultControlsStyle
 * @param {boolean} isControlsVisible
 * @return {object}
 */
var getControlsContainerStyle = function getControlsContainerStyle(defaultControlsStyle, isControlsVisible) {
  if (isControlsVisible) {
    return defaultControlsStyle;
  }

  return _extends({}, defaultControlsStyle, {
    opacity: 0,
    visibility: 'hidden'
  });
};

/**
 * get the style for the control based on backgroundColor and fontColor
 *
 * @param {object} defaultStyle
 * @param {string} backgroundColor
 * @param {string} fontColor
 * @return {object}
 */
var getControlStyle = function getControlStyle(defaultStyle, backgroundColor, fontColor) {
  if (!backgroundColor && !fontColor) {
    return defaultStyle;
  }

  var mergedStyle = {};

  if (backgroundColor) {
    mergedStyle.backgroundColor = backgroundColor;
  }

  if (fontColor) {
    mergedStyle.color = fontColor;
  }

  return _extends({}, defaultStyle, mergedStyle);
};

/**
 * get the vendor-prefixed properties associated with fullscreen activities
 *
 * @return {object}
 */
var getFullscreenProperties = function getFullscreenProperties() {
  if ('requestFullscreen' in TEST_DIV) {
    var fullscreen = 'webkitIsFullscreen' in TEST_DIV ? 'webkitIsFullScreen' : 'fullscreen';

    return {
      exitFullscreen: 'exitFullscreen',
      fullscreen: fullscreen,
      fullscreenchange: 'fullscreenchange',
      fullscreenEnabled: 'fullscreenEnabled',
      requestFullscreen: 'requestFullscreen'
    };
  }

  if ('webkitRequestFullscreen' in TEST_DIV) {
    return {
      exitFullscreen: 'webkitExitFullscreen',
      fullscreen: 'webkitIsFullScreen',
      fullscreenchange: 'webkitfullscreenchange',
      fullscreenEnabled: 'webkitFullscreenEnabled',
      requestFullscreen: 'webkitRequestFullscreen'
    };
  }

  if ('mozRequestFullScreen' in TEST_DIV) {
    return {
      exitFullscreen: 'mozCancelFullScreen',
      fullscreen: 'mozFullScreen',
      fullscreenchange: 'mozfullscreenchange',
      fullscreenEnabled: 'mozFullScreenEnabled',
      requestFullscreen: 'mozRequestFullScreen'
    };
  }

  return {
    exitFullscreen: 'exitFullscreen',
    fullscreen: 'fullscreen',
    fullscreenchange: 'fullscreenchange',
    fullscreenEnabled: 'fullscreenEnabled',
    requestFullscreen: 'requestFullscreen'
  };
};

/**
 * get the percentage played rounded to two decimal places
 *
 * @param {number} currentTime
 * @param {number} duration
 * @return {number}
 */
var getPercentPlayed = function getPercentPlayed(currentTime, duration) {
  return Math.round(currentTime / duration * 10000) / 100;
};

/**
 * based on the currentTime, show the string format as either
 * HH:MM:SS or MM:SS, based on showHours
 *
 * @param {number} currentTime
 * @param {boolean} showHours=false
 * @return {string}
 */
var getTimeFormatFromCurrentTime = function getTimeFormatFromCurrentTime(currentTime) {
  var showHours = arguments.length <= 1 || arguments[1] === undefined ? false : arguments[1];

  var integerValue = parseInt(currentTime, 10);
  var hours = Math.floor(integerValue / 3600);
  var minutes = Math.floor((integerValue - hours * 3600) / 60);
  var seconds = integerValue - hours * 3600 - minutes * 60;
  var hoursDisplay = hours < 10 ? '0' + hours : hours;
  var minutesDisplay = minutes < 10 ? '0' + minutes : minutes;
  var secondsDisplay = seconds < 10 ? '0' + seconds : seconds;

  if (showHours) {
    return hoursDisplay + ':' + minutesDisplay + ':' + secondsDisplay;
  }

  return minutesDisplay + ':' + secondsDisplay;
};

/**
 * get the vendor-prefixed CSS transform property
 *
 * @return {string}
 */
var getTransformProperty = function getTransformProperty() {
  if ('transform' in TEST_DIV.style) {
    return 'transform';
  }

  if ('WebkitTransform' in TEST_DIV.style) {
    return 'WebkitTransform';
  }

  if ('MozTransform' in TEST_DIV.style) {
    return 'MozTransform';
  }

  if ('OTransform' in TEST_DIV.style) {
    return 'OTransform';
  }

  if ('msTransform' in TEST_DIV.style) {
    return 'msTransform';
  }

  return 'transform';
};

/**
 * get the volume change style based on isVolumeChangeActive, the backgroundColor, and the fontColor
 *
 * @param {object} defaultVolumeChange
 * @param {object} volumeChangeActive
 * @param {boolean} isVolumeChangeActive
 * @param {string} backgroundColor
 * @param {string} fontColor
 * @return {object}
 */
var getVolumeChangeStyle = function getVolumeChangeStyle(defaultVolumeChange, volumeChangeActive, isVolumeChangeActive, backgroundColor, fontColor) {
  if (!isVolumeChangeActive) {
    return defaultVolumeChange;
  }

  if (backgroundColor || fontColor) {
    var mergedStyle = {};

    if (backgroundColor) {
      mergedStyle.backgroundColor = backgroundColor;
    }

    if (fontColor) {
      mergedStyle.color = fontColor;
    }

    return _extends({}, defaultVolumeChange, volumeChangeActive, mergedStyle);
  }

  return _extends({}, defaultVolumeChange, volumeChangeActive);
};

/**
 * get the volume icon based on the volume and isMuted
 *
 * @param {number} volume
 * @param {boolean} isMuted
 * @return {string}
 */
var getVolumeIcon = function getVolumeIcon(volume, isMuted) {
  switch (true) {
    case isMuted:
      return _icons.availableIcons.VOLUME_MUTE;

    case volume >= 0.67:
      return _icons.availableIcons.VOLUME_HIGH;

    case volume >= 0.33:
      return _icons.availableIcons.VOLUME_MEDIUM;

    default:
      return _icons.availableIcons.VOLUME_LOW;
  }
};

exports.getControlsContainerStyle = getControlsContainerStyle;
exports.getControlStyle = getControlStyle;
exports.getFullscreenProperties = getFullscreenProperties;
exports.getTimeFormatFromCurrentTime = getTimeFormatFromCurrentTime;
exports.getPercentPlayed = getPercentPlayed;
exports.getTransformProperty = getTransformProperty;
exports.getVolumeChangeStyle = getVolumeChangeStyle;
exports.getVolumeIcon = getVolumeIcon;
exports.default = {
  getControlsContainerStyle: getControlsContainerStyle,
  getControlStyle: getControlStyle,
  getFullscreenProperties: getFullscreenProperties,
  getTimeFormatFromCurrentTime: getTimeFormatFromCurrentTime,
  getPercentPlayed: getPercentPlayed,
  getTransformProperty: getTransformProperty,
  getVolumeIcon: getVolumeIcon
};